@@ -13,13 +13,9 @@ def setup_terrier(file_path):
         print('JAR file not found, downloading')
         url = 'https://repo.maven.apache.org/maven2/org/terrier/terrier-assemblies/5.1/terrier-assemblies-5.1-jar-with-dependencies.jar'
         wget.download(url, file_path)
-    # import jnius_config
-    # jnius_config.add_classpath("./terrier-assemblies-5.1-jar-with-dependencies.jar")
-    # from jnius import autoclass, cast
-    # from utils import Utils
-    # from batchretrieve import BatchRetrieve, FeaturesBatchRetrieve
 
 file_path = os.path.dirname(os.path.abspath(__file__))
+print(file_path)
 setup_terrier(file_path)
 import jnius_config
 jnius_config.add_classpath(os.path.join(file_path,"terrier-assemblies-5.1-jar-with-dependencies.jar"))
